{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "phmmer"
            ],
            "inputs": [
                {
                    "id": "#phmmer-v3.2.cwl/bitscoreThreshold",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-T"
                    },
                    "label": "report sequences >= this bit score threshold in output"
                },
                {
                    "id": "#phmmer-v3.2.cwl/cpu",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cpu"
                    },
                    "label": "Number of parallel CPU workers to use for multithreads"
                },
                {
                    "id": "#phmmer-v3.2.cwl/seqFile",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "Query sequence(s) file",
                    "doc": "Search one or more query protein sequences against a protein sequence database.\n"
                },
                {
                    "id": "#phmmer-v3.2.cwl/seqdb",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 2
                    },
                    "label": "Target database of sequences"
                }
            ],
            "doc": "The phmmer and jackhmmer programs search a single protein sequence against a protein sequence database, akin to BLASTP and PSIBLAST, respectively. (Internally, they just produce a profile HMM from the query sequence, then run HMM searches.) Please visit https://github.com/EddyRivasLab/hmmer for full documentation.\nReleases can be downloaded from https://github.com/EddyRivasLab/hmmer/releases\n",
            "label": "Search a single protein sequence against a protein sequence database. (BLASTP-like)",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--tblout",
                    "valueFrom": "$(inputs.seqFile.basename).phmmer_matches.tblout"
                },
                {
                    "position": 0,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.seqFile.basename).phmmer_matches.out"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1024,
                    "coresMin": 2,
                    "coresMax": 4
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2--hfc679d8_3"
                },
                {
                    "class": "http://galaxyproject.org/cwl#interface",
                    "http://galaxyproject.org/cwl#inputs": [
                        {
                            "http://galaxyproject.org/cwl#name": "bitscoreThreshold",
                            "http://galaxyproject.org/cwl#type": "integer",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "cpu",
                            "http://galaxyproject.org/cwl#type": "integer",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "seqFile",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt"
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "seqdb",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt"
                        }
                    ]
                }
            ],
            "id": "#phmmer-v3.2.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew",
            "outputs": [
                {
                    "id": "#phmmer-v3.2.cwl/matches",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.seqFile.basename).phmmer_matches.tblout"
                    }
                },
                {
                    "id": "#phmmer-v3.2.cwl/programOutput",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.seqFile.basename).phmmer_matches.out"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cat"
            ],
            "inputs": [
                {
                    "id": "#concatenate.cwl/files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true
                },
                {
                    "id": "#concatenate.cwl/outputFileName",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#concatenate.cwl/result",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFileName)",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    }
                }
            ],
            "doc": "The cat (short for \u201cconcatenate\u201c) command is one of the most frequently used command in Linux/Unix like operating systems. cat command allows us to create single or multiple files, view contain of file, concatenate files and redirect output in terminal or files.\n",
            "label": "Redirecting Multiple Files Contain in a Single File",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 100,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "stdout": "$(inputs.outputFileName)",
            "id": "#concatenate.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python3"
            ],
            "inputs": [
                {
                    "id": "#fasta_chunker.cwl/chunk_size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 10
                },
                {
                    "id": "#fasta_chunker.cwl/seqs",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929"
                }
            ],
            "outputs": [
                {
                    "id": "#fasta_chunker.cwl/chunks",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "chunks/*_*.fasta"
                    },
                    "format": "http://edamontology.org/format_1929"
                }
            ],
            "doc": "based upon code by developers from EMBL-EBI",
            "label": "split FASTA by number of records",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "-c",
                    "valueFrom": "from Bio import SeqIO\nimport os\ncurrentSequences = []\nos.mkdir(\"$(runtime.outdir)/chunks\")\nfor record in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    currentSequences.append(record)\n    if len(currentSequences) == $(inputs.chunk_size):\n        fileName = currentSequences[0].id + \"_\" + currentSequences[-1].id + \".fasta\"\n        for char in [ \"/\", \" \", \":\" ]:\n            fileName = fileName.replace(char, \"_\")\n        SeqIO.write(currentSequences, \"$(runtime.outdir)/chunks/\"+fileName, \"fasta\")\n        currentSequences = []\n\n# write any remaining sequences\nif len(currentSequences) > 0:\n    fileName = currentSequences[0].id + \"_\" + currentSequences[-1].id + \".fasta\"\n    for char in [ \"/\", \" \", \":\" ]:\n        fileName = fileName.replace(char, \"_\")\n    SeqIO.write(currentSequences, \"$(runtime.outdir)/chunks/\"+fileName, \"fasta\")\n"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 100,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biopython/biopython:latest"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69",
                                "1.72"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "Workflow",
            "label": "Chunked version of phmmer-v3.2.cwl",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/bitscoreThreshold",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-T"
                    },
                    "label": "report sequences >= this bit score threshold in output"
                },
                {
                    "id": "#main/cpu",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cpu"
                    },
                    "label": "Number of parallel CPU workers to use for multithreads"
                },
                {
                    "id": "#main/seqFile",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "Query sequence(s) file",
                    "doc": "Search one or more query protein sequences against a protein sequence database.\n"
                },
                {
                    "id": "#main/seqdb",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "label": "Target database of sequences"
                },
                {
                    "id": "#main/fullPhmmerMatches",
                    "type": "string",
                    "default": "full_phmmer_matches"
                },
                {
                    "id": "#main/fullPhmmerOutput",
                    "type": "string",
                    "default": "full_phmmer_output"
                }
            ],
            "outputs": [
                {
                    "id": "#main/matches",
                    "type": "File",
                    "outputSource": "#main/combine_phmmer_matches/result"
                },
                {
                    "id": "#main/programOutput",
                    "type": "File",
                    "outputSource": "#main/combine_phmmer_output/result"
                }
            ],
            "steps": [
                {
                    "label": "Calculates phmmer matches on chunked sequence files",
                    "run": "#phmmer-v3.2.cwl",
                    "in": [
                        {
                            "source": "#main/split_seqs/chunks",
                            "id": "#main/calculate_phmmer_matches/seqFile"
                        },
                        {
                            "source": "#main/seqdb",
                            "id": "#main/calculate_phmmer_matches/seqdb"
                        }
                    ],
                    "scatter": "#main/calculate_phmmer_matches/seqFile",
                    "out": [
                        "#main/calculate_phmmer_matches/matches",
                        "#main/calculate_phmmer_matches/programOutput"
                    ],
                    "id": "#main/calculate_phmmer_matches"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/calculate_phmmer_matches/matches",
                            "id": "#main/combine_phmmer_matches/files"
                        },
                        {
                            "source": "#main/fullPhmmerMatches",
                            "id": "#main/combine_phmmer_matches/outputFileName"
                        }
                    ],
                    "out": [
                        "#main/combine_phmmer_matches/result"
                    ],
                    "id": "#main/combine_phmmer_matches"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/calculate_phmmer_matches/programOutput",
                            "id": "#main/combine_phmmer_output/files"
                        },
                        {
                            "source": "#main/fullPhmmerOutput",
                            "id": "#main/combine_phmmer_output/outputFileName"
                        }
                    ],
                    "out": [
                        "#main/combine_phmmer_output/result"
                    ],
                    "id": "#main/combine_phmmer_output"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 500,
                            "id": "#main/split_seqs/chunk_size"
                        },
                        {
                            "source": "#main/seqFile",
                            "id": "#main/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#main/split_seqs/chunks"
                    ],
                    "id": "#main/split_seqs"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Maxim Scheremetjew"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.20.owl",
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
